;
; AutoHotkey Version: 1.x
; Language:       English
; Platform:       Win9x/NT
; Author:         Jim Foltz <jim.foltz@gmail.com>
; AutoHotKey Ver  1.0.48.05
;
; Script Function:
;    Various enahacements to the SketchUp Ruby Console
;

/*
== Keys ==

Context: Ruby Console Active
  Ctl+l: Clear the Ruby Console (Default)
  Ctl-a: Select Entry line
  UP   : Unchanged, but puts cursor at end of line.
  Down : Unchanged, but puts cursor at end of line. 
  Alt-s: Shade/Unshade Ruby Console (Default)

Ruby Console Open, but not Active
  Ctl-f: Switch Focus
  Alt-s: Toggle Shade

*/

;==========================================
; Hotkeys for SketchUp/Ruby Console
;==========================================

SendMode Input
#NoEnv

AppName = SketchUp Hotkeys
IniFIle = %AppName%.ini

RubyConsole = Ruby Console
rre := "(Untitled|.*\.skp) - SketchUp|"RubyConsole
GroupAdd, SuGroup, % "ahk_id " MainWindowId()
GroupAdd, SuGroup, % "ahk_id " GetRubyConsoleId()

Menu, Tray, NoStandard
Menu, Tray, Add, Quit, mnuQuit
Menu, Tray, Add, Suspend Keys, mnuSuspend
Menu, Tray, Add, Customize, GuiCreate
Menu, Tray, Default, Suspend Keys

ShowSplash(3)

InitKeys:
    IniRead, cls, %IniFIle%, Hotkeys, ClearRubyConsoleKey, ^l
    IniRead, sha, %IniFIle%, Hotkeys, ShadeRubyConsoleKey, !s
    IniRead, foc, %IniFIle%, Hotkeys, FocusKey           , ^f

    Hotkey, IfWinActive, ahk_group SuGroup

    Hotkey, %cls%, lblCLS  , On
    Hotkey, %sha%, lblShade, On
    Hotkey, %foc%, lblFocus, On
Return

mnuSuspend:
    Menu, Tray, ToggleCheck, Suspend Keys
    Suspend
Return

mnuQuit:
    MsgBox,,Bye, Exiting SketchUp Hotkeys,1
    ExitApp
Return

GuiCreate:
    Gui, Destroy
    Gui, Add, Text,, Configure Hotkeys for SketchUp
    Gui, Add, Text,Section, Clear Ruby Console
    Gui, Add, Hotkey, ys vhkCls, %cls%
    Gui, Add, Text, xs Section , Shade
    Gui, Add, Hotkey, x+72 ys vhkKeyShade, %sha% 
    Gui, Add, Text, xs Section, Focus
    Gui, Add, Hotkey, x+74 ys vhkFocus, %foc%
    Gui, Add, Button, Section Default, Accept
    Gui, Add, Button, ys, Cancel
    Gui, Show
Return

ButtonCancel:
    Gui, Destroy
Return

ButtonAccept:
    Gui, Submit
    Hotkey, IfWinActive, ahk_group SuGroup
    Hotkey, %hkKeyShade%, lblShade, On
    Hotkey, %hkCls%     , lblCLS  , On
    Hotkey, %hkFocus%   , lblFocus, On
    Hotkey, IfWinActive

    IniWrite, %hkCls%, %IniFIle%, Hotkeys, ClearRubyConsoleKey
    IniWrite, %hkKeyShade%, %IniFIle%, Hotkeys, ShadeRubyConsoleKey
    IniWrite, %hkFocus%, %IniFIle%, Hotkeys, FocusKey
Return

lblShade:
    ShadeToggle()
Return

lblCLS:
    ClearRubyConsole()
Return

lblFocus:
    SwapFocus()
Return

#IfWinActive, ahk_group SuGroup
{

} ; END CONTEXT
#IfWinActive

#IfWinActive, Ruby Console
{
; Ctrl-a: Select all in the Ruby Console input
^a::
    ControlGetFocus, ctrl, Ruby Console
    If ctrl = Edit1 ; Focus in input area
        Send, {Home}+{End}
Return
~Up::Send, {End}
~DOWN::Send, {End}
}
#IfWinActive

/*
 *
 * Functions Below
 *
*/

ShowSplash(t)
{
    MsgBox,,SketchUp Hotkeys,Hotkeys for SketchUp.`njim.foltz@gmail.com`n`nRight-click Tray menu for options.,%t% 
}

ClearRubyConsole()
{
    ; save the current input
    ControlGetText, line, Edit1, Ruby Console
    ; Clear the input
    ControlSetText, Edit1,,Ruby Console
    ; Clear the output
    ControlSetText, Edit2,,Ruby Console
    ; Send the Enter key to reset buffered text
    ControlSend, Edit1, {Enter}
    ; Restore previous input text
    ControlSetText, Edit1,%line%,Ruby Console
    ; set focus 
    ControlFocus, Edit1, Ruby Console
    ; Move the cursor to the end of the line
    Send, {End}
}

SketchUpActive()
{
    WinGetActiveTitle, t
    Return RegExMatch(t, rre)
}

MainWindowId()
{
    tmm = %A_TitleMatchMode%
    SetTitleMatchMode, RegEx
    ;win := WinExist("(Untitled|.*\.skp) - SketchUp")
    WinGet, win, ID, (Untitled|.*\.skp) - SketchUp
    ;MsgBox,,, win: %win%, 1
    SetTitleMatchMode, %tmm%
    Return win
}

GetRubyConsoleId()
{
    global RubyConsole
    WinGet, rid, ID, %RubyConsole%
    return rid
}

SwapFocus()
{
    global SuGroup
    GroupActivate, SuGroup
}

ShadeToggle()
{
    static shaded, last_h
    default_h = 310

    WinGet, id, ID, Ruby Console

    If id=
    {
        MsgBox, No id:<%id%>, returning.
        Return
    }
    WinGetPos, x, y, w, h, ahk_id %id%
    If h = 80
    {
        shaded := true
        last_h := last_h <= 80 ? default_h : last_h
    }
    If shaded=
    {
        last_h := h
        WinMove, ahk_id %id%,, %x%, %y%, %w%, 80
        shaded := true
    }
    Else
    {
        WinMove, ahk_id %id%,, %x%, %y%, %w%, %last_h%
        shaded =
    }
}

#IfWinActive, SketchUp.ahk (~\My Documents\Dev\ahk) - GVIM
+F12::
Send, ^s
MsgBox,,Reloading,Reloading: %A_ScriptName%, 1
Reload
#IfWinACtive
